%------------------------------------------------------------------------------
%  CompareWithHoechle.m
%
%
%  This file imports the data from a csv file created by Stata (Hoechle's data) and then
%  runs the regressions.
%
%  Compare the results to Table 2 in Hoechle, 2007, "Robust Standard Errors...", Stata
%  Journal, 7, 281-312.
%
%
%
%
%
%
%
%  Paul.Soderlind@unisg.ch   19 December 2011
%------------------------------------------------------------------------------


clear;clc;close all;
%------------------------------------------------------------------------------


%Filename = 'HoechleData\bidaskspread.csv';                      %load the data
Filename  = 'bidaskspread.csv';                      %load the data
xTN = StataToMLPanelDataPs(Filename,1,[],1,'mm/dd/yyyy',11,2,[],',',[],[],[]);

%{
for k = 1:size(xTN,3);
 disp(' ');
 disp(Table3Ps(xTN(:,:,k)));
end;
%}

BA    = xTN(:,:,4);
TRMS  = xTN(:,:,5);
TRMS2 = xTN(:,:,6);
aVol  = xTN(:,:,7);
Size  = xTN(:,:,8);

[T,N] = size(BA);
%------------------------------------------------------------------------------

disp('Pooled OLS');
x = [vecr(aVol),vecr(Size),vecr(TRMS2),vecr(TRMS),vecr(ones(T,N))];
y = vecr(BA);    %stack rows in column vector

yx = excise([y,x]);
y  = yx(:,1);
x  = yx(:,2:end);
clear yx;
b    = x\y;
res  = y - x*b;
Covb = inv(x'*x)*var(res,1);
Stdb = sqrt(diag(Covb));
disp('b, Std and tstat from OLS');disp([b,Stdb,b./Stdb]);

clear x y res;
%------------------------------------------------------------------------------

disp('HszDk5cPs, effectively weighting all periods equally, irrespective of number of obs');
x = ones(T,1);
z = cat(3,aVol,Size,TRMS2,TRMS,ones(T,N));
[theta,stdDK,stdW,CovDK,yhat,R2,CovW,CovDKj,stdDKj] = HszDk5cPs(BA,x,z,0,8,1);

disp('theta, std and t-stat');
disp([theta,stdDKj,theta./stdDKj]);
%------------------------------------------------------------------------------

disp('HszDk5cPs, effectively weighting all obs equally');
x = ones(T,1);
z = cat(3,aVol,Size,TRMS2,TRMS,ones(T,N));
[theta,stdDK,stdW,CovDK,yhat,R2,CovW,CovDKj,stdDKj] = HszDk5cPs(BA,x,z,0,8,0);

disp('theta, std and t-stat');
disp([theta,stdDKj,theta./stdDKj]);
%------------------------------------------------------------------------------
